@@ -97,7 +97,7 @@ private:
         }
         else if (hole.shape == Hole::Shape::SLOT) {
             int64_t box_width = hole.length - hole.diameter;
-            {
+            if (box_width > 0) {
                 TopoDS_Shape s = BRepPrimAPI_MakeBox(gp_Pnt(-box_width / 2e6, hole.diameter / -2e6, 0), box_width / 1e6,
                                                      hole.diameter / 1e6, thickness * 2e-6)
                                          .Shape();
@@ -372,7 +372,8 @@ static double angle_to_rad(int angle)
 }
 
 void export_step(const std::string &filename, const Board &brd, class Pool &pool, bool include_models,
-                 std::function<void(std::string)> progress_cb, const Board::Colors *colors, const std::string &prefix)
+                 std::function<void(const std::string &)> progress_cb, const BoardColors *colors,
+                 const std::string &prefix)
 {
     auto app = XCAFApp_Application::GetApplication();
     Handle(TDocStd_Document) doc;
@@ -388,7 +389,7 @@ void export_step(const std::string &filename, const Board &brd, class Pool &pool
     {
         CanvasPatch canvas;
         canvas.update(brd);
-        for (const auto &it : canvas.patches) {
+        for (const auto &it : canvas.get_patches()) {
             if (it.first.layer == BoardLayers::L_OUTLINE) {
                 cl.AddPaths(it.second, ClipperLib::ptSubject, true);
             }
