@@ -2,11 +2,12 @@
 #include <string>
 #include <vector>
 #include <gdk/gdk.h>
-#include "core/tool_id.hpp"
 #include <functional>
 
 namespace horizon {
 
+enum class ToolID;
+
 enum class ActionID {
     NONE,
     TOOL,
@@ -77,7 +78,13 @@ enum class ActionID {
     SELECT_MORE,
     SELECT_MORE_NO_VIA,
     STEP_EXPORT_WINDOW,
-    EXPORT_STEP
+    EXPORT_STEP,
+    PNP_EXPORT_WINDOW,
+    EXPORT_PNP,
+    RESET_AIRWIRE_FILTER,
+    FILTER_AIRWIRES,
+    AIRWIRE_FILTER_WINDOW,
+    SELECT_POLYGON
 };
 
 enum class ActionGroup {
