@@ -1,7 +1,6 @@
 #pragma once
 #include "core/clipboard.hpp"
 #include "core/core.hpp"
-#include "core/cores.hpp"
 #include "imp_interface.hpp"
 #include "keyseq_dialog.hpp"
 #include "main_window.hpp"
@@ -12,7 +11,10 @@
 #include "widgets/spin_button_dim.hpp"
 #include "widgets/warnings_box.hpp"
 #include "action.hpp"
+#include "nlohmann/json.hpp"
+#include "search/searcher.hpp"
 #include <zmq.hpp>
+#include "util/item_set.hpp"
 
 #ifdef G_OS_WIN32
 #undef DELETE
@@ -63,6 +65,10 @@ public:
     };
 
     virtual std::map<ObjectType, SelectionFilterInfo> get_selection_filter_info() const;
+    virtual bool is_layered() const
+    {
+        return false;
+    };
 
 protected:
     MainWindow *main_window;
@@ -75,7 +81,7 @@ protected:
     std::unique_ptr<SelectionFilterDialog> selection_filter_dialog;
 
     std::unique_ptr<Pool> pool;
-    Cores core;
+    class Core *core = nullptr;
     std::unique_ptr<ClipboardManager> clipboard = nullptr;
     std::unique_ptr<KeySequenceDialog> key_sequence_dialog = nullptr;
     std::unique_ptr<ImpInterface> imp_interface = nullptr;
@@ -96,7 +102,9 @@ protected:
     bool no_update = false;
 
     virtual void canvas_update() = 0;
-    void sc(void);
+    virtual void expand_selection_for_property_panel(std::set<SelectableRef> &sel_extra,
+                                                     const std::set<SelectableRef> &sel);
+    void handle_selection_changed(void);
     bool handle_key_press(GdkEventKey *key_event);
     void handle_cursor_move(const Coordi &pos);
     bool handle_click(GdkEventButton *button_event);
@@ -153,7 +161,7 @@ protected:
     std::string get_hud_text_for_net(const Net *net);
 
     void set_monitor_files(const std::set<std::string> &files);
-    void set_monitor_items(const std::set<std::pair<ObjectType, UUID>> &items);
+    void set_monitor_items(const ItemSet &items);
     virtual void update_monitor()
     {
     }
@@ -165,11 +173,43 @@ protected:
 
     void tool_update_data(std::unique_ptr<ToolData> &data);
 
-    virtual void search_center(const Core::SearchResult &res);
+    virtual void search_center(const Searcher::SearchResult &res);
     virtual std::pair<ActionID, ToolID> get_doubleclick_action(ObjectType type, const UUID &uu);
 
     Glib::RefPtr<Gio::Menu> hamburger_menu;
 
+    json m_meta;
+    void load_meta();
+    static const std::string meta_suffix;
+
+    virtual void get_save_meta(json &j)
+    {
+    }
+
+    void set_window_title(const std::string &s);
+    void set_window_title_from_block();
+
+    void update_view_hints();
+    virtual std::vector<std::string> get_view_hints();
+
+    virtual Searcher *get_searcher_ptr()
+    {
+        return nullptr;
+    }
+
+    bool has_searcher()
+    {
+        return get_searcher_ptr();
+    }
+
+    Searcher &get_searcher()
+    {
+        auto s = get_searcher_ptr();
+        if (!s)
+            throw std::runtime_error("not implemented");
+        return *s;
+    }
+
 private:
     void fix_cursor_pos();
     Glib::RefPtr<Gio::FileMonitor> preferences_monitor;
@@ -192,15 +232,16 @@ private:
     KeySequence keys_current;
     bool handle_action_key(GdkEventKey *ev);
     void handle_tool_action(const ActionConnection &conn);
+    void handle_select_polygon(const ActionConnection &a);
 
     void handle_search();
     void search_go(int dir);
-    std::list<Core::SearchResult> search_results;
+    std::list<Searcher::SearchResult> search_results;
     unsigned int search_result_current = 0;
     void update_search_markers();
     void update_search_types_label();
     void set_search_mode(bool enabled, bool focus = true);
-    std::map<ObjectType, Gtk::CheckButton *> search_check_buttons;
+    std::map<Searcher::Type, Gtk::CheckButton *> search_check_buttons;
 
     class LogWindow *log_window = nullptr;
     std::set<SelectableRef> selection_for_drag_move;
@@ -220,5 +261,7 @@ private:
     void show_sockets_broken_dialog(const std::string &msg = "");
     bool needs_autosave = false;
     bool queue_autosave = false;
+
+    void update_property_panels();
 };
 } // namespace horizon
