@@ -7,18 +7,21 @@
 #include "util/gtk_util.hpp"
 #include "util/util.hpp"
 #include "util/str_util.hpp"
-#include "hud_util.hpp"
+#include "util/selection_util.hpp"
 #include "bom_export_window.hpp"
 #include "pdf_export_window.hpp"
 #include "nlohmann/json.hpp"
-#include "core/tool_backannotate_connection_lines.hpp"
-#include "core/tool_add_part.hpp"
+#include "core/tools/tool_backannotate_connection_lines.hpp"
+#include "core/tools/tool_add_part.hpp"
+#include "core/tools/tool_map_symbol.hpp"
+#include "widgets/unplaced_box.hpp"
+#include "core/tool_id.hpp"
 
 namespace horizon {
 ImpSchematic::ImpSchematic(const std::string &schematic_filename, const std::string &block_filename,
                            const PoolParams &pool_params)
     : ImpBase(pool_params), core_schematic(schematic_filename, block_filename, *pool),
-      project_dir(Glib::path_get_dirname(schematic_filename))
+      project_dir(Glib::path_get_dirname(schematic_filename)), searcher(core_schematic)
 {
     core = &core_schematic;
     core_schematic.signal_tool_changed().connect(sigc::mem_fun(*this, &ImpSchematic::handle_tool_change));
@@ -172,6 +175,10 @@ bool ImpSchematic::handle_broadcast(const json &j)
                 tool_begin(ToolID::BACKANNOTATE_CONNECTION_LINES, true, {}, std::move(data));
             }
         }
+        else if (op == "edit-meta" && !core_schematic.tool_is_active()) {
+            main_window->present(timestamp);
+            tool_begin(ToolID::EDIT_SCHEMATIC_PROPERTIES);
+        }
     }
     return true;
 }
@@ -243,8 +250,6 @@ int ImpSchematic::get_board_pid()
 
 void ImpSchematic::construct()
 {
-
-    main_window->set_title("Schematic - Interactive Manipulator");
     state_store = std::make_unique<WindowStateStore>(main_window, "imp-schematic");
 
     sheet_box = Gtk::manage(new SheetBox(&core_schematic));
@@ -300,7 +305,7 @@ void ImpSchematic::construct()
         auto button = Gtk::manage(new Gtk::Button("Place part"));
         button->signal_clicked().connect([this] { trigger_action(ActionID::PLACE_PART); });
         button->show();
-        core.r->signal_tool_changed().connect([button](ToolID t) { button->set_sensitive(t == ToolID::NONE); });
+        core->signal_tool_changed().connect([button](ToolID t) { button->set_sensitive(t == ToolID::NONE); });
         main_window->header->pack_end(*button);
     }
 
@@ -309,10 +314,9 @@ void ImpSchematic::construct()
             this->tool_begin(ToolID::ADD_PART);
         }
         else {
-            auto ev = gtk_get_current_event();
             json j;
             j["op"] = "show-browser";
-            j["time"] = gdk_event_get_time(ev);
+            j["time"] = gtk_get_current_event_time();
             allow_set_foreground_window(mgr_pid);
             this->send_json(j);
         }
@@ -320,10 +324,9 @@ void ImpSchematic::construct()
 
     if (sockets_connected) {
         connect_action(ActionID::TO_BOARD, [this](const auto &conn) {
-            auto ev = gtk_get_current_event();
             json j;
             j["op"] = "to-board";
-            j["time"] = gdk_event_get_time(ev);
+            j["time"] = gtk_get_current_event_time();
             j["selection"] = nullptr;
             for (const auto &it : canvas->get_selection()) {
                 auto sheet = core_schematic.get_sheet();
@@ -365,18 +368,16 @@ void ImpSchematic::construct()
 
         connect_action(ActionID::SAVE_RELOAD_NETLIST, [this](const auto &conn) {
             this->trigger_action(ActionID::SAVE);
-            auto ev = gtk_get_current_event();
             json j;
-            j["time"] = gdk_event_get_time(ev);
+            j["time"] = gtk_get_current_event_time();
             j["op"] = "reload-netlist";
             this->send_json(j);
         });
         set_action_sensitive(make_action(ActionID::SAVE_RELOAD_NETLIST), false);
 
         connect_action(ActionID::GO_TO_BOARD, [this](const auto &conn) {
-            auto ev = gtk_get_current_event();
             json j;
-            j["time"] = gdk_event_get_time(ev);
+            j["time"] = gtk_get_current_event_time();
             j["op"] = "present-board";
             auto board_pid = this->get_board_pid();
             if (board_pid != -1)
@@ -457,11 +458,11 @@ void ImpSchematic::construct()
     });
 
     bom_export_window->signal_changed().connect([this] { core_schematic.set_needs_save(); });
-    core.r->signal_tool_changed().connect([this](ToolID t) { bom_export_window->set_can_export(t == ToolID::NONE); });
-    core.r->signal_rebuilt().connect([this] { bom_export_window->update(); });
+    core->signal_tool_changed().connect([this](ToolID t) { bom_export_window->set_can_export(t == ToolID::NONE); });
+    core->signal_rebuilt().connect([this] { bom_export_window->update(); });
 
-    pdf_export_window = PDFExportWindow::create(main_window, &core_schematic, *core_schematic.get_pdf_export_settings(),
-                                                project_dir);
+    pdf_export_window = PDFExportWindow::create(main_window, dynamic_cast<IDocument *>(&core_schematic),
+                                                *core_schematic.get_pdf_export_settings(), project_dir);
     pdf_export_window->signal_changed().connect([this] { core_schematic.set_needs_save(); });
     connect_action(ActionID::PDF_EXPORT_WINDOW, [this](const auto &c) { pdf_export_window->present(); });
     connect_action(ActionID::EXPORT_PDF, [this](const auto &c) {
@@ -469,6 +470,18 @@ void ImpSchematic::construct()
         pdf_export_window->generate();
     });
 
+    unplaced_box = Gtk::manage(new UnplacedBox("Symbol"));
+    unplaced_box->show();
+    main_window->left_panel->pack_end(*unplaced_box, true, true, 0);
+    unplaced_box->signal_place().connect([this](const auto &items) {
+        auto d = std::make_unique<ToolMapSymbol::ToolDataMapSymbol>(items);
+        this->tool_begin(ToolID::MAP_SYMBOL, false, {}, std::move(d));
+    });
+    core_schematic.signal_rebuilt().connect(sigc::mem_fun(*this, &ImpSchematic::update_unplaced));
+    update_unplaced();
+    core_schematic.signal_tool_changed().connect(
+            [this](ToolID tool_id) { unplaced_box->set_sensitive(tool_id == ToolID::NONE); });
+
     grid_spin_button->set_sensitive(false);
     canvas->snap_to_targets = false;
 
@@ -491,6 +504,9 @@ void ImpSchematic::construct()
         target_drag_begin = Target();
         return false;
     });
+
+    if (!core_schematic.get_project_meta_loaded_from_block())
+        core_schematic.set_needs_save();
 } // namespace horizon
 
 void ImpSchematic::update_action_sensitivity()
@@ -553,7 +569,7 @@ std::string ImpSchematic::get_hud_text(std::set<SelectableRef> &sel)
 {
     std::string s;
     if (sel_count_type(sel, ObjectType::SCHEMATIC_SYMBOL) == 1) {
-        const auto &sym = core_schematic.get_sheet()->symbols.at(sel_find_one(sel, ObjectType::SCHEMATIC_SYMBOL));
+        const auto &sym = core_schematic.get_sheet()->symbols.at(sel_find_one(sel, ObjectType::SCHEMATIC_SYMBOL).uuid);
         s += "<b>Symbol " + sym.component->refdes + "</b>\n";
         s += get_hud_text_for_component(sym.component);
         sel_erase_type(sel, ObjectType::SCHEMATIC_SYMBOL);
@@ -657,7 +673,7 @@ void ImpSchematic::handle_drag()
             update_highlights();
             ToolArgs args;
             args.coords = target_drag_begin.p;
-            ToolResponse r = core.r->tool_begin(ToolID::DRAW_NET, args, imp_interface.get());
+            ToolResponse r = core->tool_begin(ToolID::DRAW_NET, args, imp_interface.get());
             tool_process(r);
         }
         {
@@ -667,14 +683,14 @@ void ImpSchematic::handle_drag()
             args.button = 1;
             args.target = target_drag_begin;
             args.work_layer = canvas->property_work_layer();
-            ToolResponse r = core.r->tool_update(args);
+            ToolResponse r = core->tool_update(args);
             tool_process(r);
         }
         target_drag_begin = Target();
     }
 }
 
-void ImpSchematic::search_center(const Core::SearchResult &res)
+void ImpSchematic::search_center(const Searcher::SearchResult &res)
 {
     if (res.sheet != core_schematic.get_sheet()->uuid) {
         sheet_box->select_sheet(res.sheet);
@@ -748,24 +764,24 @@ void ImpSchematic::handle_move_to_other_sheet(const ActionConnection &conn)
         for (const auto &it : selection) {
             switch (it.type) {
             case ObjectType::NET_LABEL: {
-                auto &la = core.c->get_sheet()->net_labels.at(it.uuid);
+                auto &la = core_schematic.get_sheet()->net_labels.at(it.uuid);
                 new_sel.emplace(la.junction->uuid, ObjectType::JUNCTION);
             } break;
             case ObjectType::BUS_LABEL: {
-                auto &la = core.c->get_sheet()->bus_labels.at(it.uuid);
+                auto &la = core_schematic.get_sheet()->bus_labels.at(it.uuid);
                 new_sel.emplace(la.junction->uuid, ObjectType::JUNCTION);
             } break;
             case ObjectType::POWER_SYMBOL: {
-                auto &ps = core.c->get_sheet()->power_symbols.at(it.uuid);
+                auto &ps = core_schematic.get_sheet()->power_symbols.at(it.uuid);
                 new_sel.emplace(ps.junction->uuid, ObjectType::JUNCTION);
             } break;
             case ObjectType::BUS_RIPPER: {
-                auto &rip = core.c->get_sheet()->bus_rippers.at(it.uuid);
+                auto &rip = core_schematic.get_sheet()->bus_rippers.at(it.uuid);
                 new_sel.emplace(rip.junction->uuid, ObjectType::JUNCTION);
             } break;
 
             case ObjectType::LINE_NET: {
-                auto line = &core.c->get_sheet()->net_lines.at(it.uuid);
+                auto line = &core_schematic.get_sheet()->net_lines.at(it.uuid);
                 for (auto &it_ft : {line->from, line->to}) {
                     if (it_ft.is_junc()) {
                         new_sel.emplace(it_ft.junc->uuid, ObjectType::JUNCTION);
@@ -780,21 +796,21 @@ void ImpSchematic::handle_move_to_other_sheet(const ActionConnection &conn)
             } break;
 
             case ObjectType::LINE: {
-                auto line = &core.c->get_sheet()->lines.at(it.uuid);
+                auto line = &core_schematic.get_sheet()->lines.at(it.uuid);
                 for (auto &it_ft : {line->from, line->to}) {
                     new_sel.emplace(it_ft->uuid, ObjectType::JUNCTION);
                 }
             } break;
 
             case ObjectType::ARC: {
-                auto arc = &core.c->get_sheet()->arcs.at(it.uuid);
+                auto arc = &core_schematic.get_sheet()->arcs.at(it.uuid);
                 for (auto &it_ft : {arc->from, arc->to, arc->center}) {
                     new_sel.emplace(it_ft->uuid, ObjectType::JUNCTION);
                 }
             } break;
 
             case ObjectType::SCHEMATIC_SYMBOL: {
-                auto sym = core.c->get_schematic_symbol(it.uuid);
+                auto sym = core_schematic.get_schematic_symbol(it.uuid);
                 for (const auto &itt : sym->texts) {
                     new_sel.emplace(itt->uuid, ObjectType::TEXT);
                 }
@@ -805,27 +821,27 @@ void ImpSchematic::handle_move_to_other_sheet(const ActionConnection &conn)
         }
 
         // other direction
-        for (const auto &it : core.c->get_sheet()->net_labels) {
+        for (const auto &it : core_schematic.get_sheet()->net_labels) {
             if (selection.count(SelectableRef(it.second.junction->uuid, ObjectType::JUNCTION))) {
                 new_sel.emplace(it.first, ObjectType::NET_LABEL);
             }
         }
-        for (const auto &it : core.c->get_sheet()->bus_labels) {
+        for (const auto &it : core_schematic.get_sheet()->bus_labels) {
             if (selection.count(SelectableRef(it.second.junction->uuid, ObjectType::JUNCTION))) {
                 new_sel.emplace(it.first, ObjectType::BUS_LABEL);
             }
         }
-        for (const auto &it : core.c->get_sheet()->bus_rippers) {
+        for (const auto &it : core_schematic.get_sheet()->bus_rippers) {
             if (selection.count(SelectableRef(it.second.junction->uuid, ObjectType::JUNCTION))) {
                 new_sel.emplace(it.first, ObjectType::BUS_RIPPER);
             }
         }
-        for (const auto &it : core.c->get_sheet()->power_symbols) {
+        for (const auto &it : core_schematic.get_sheet()->power_symbols) {
             if (selection.count(SelectableRef(it.second.junction->uuid, ObjectType::JUNCTION))) {
                 new_sel.emplace(it.first, ObjectType::POWER_SYMBOL);
             }
         }
-        for (const auto &it : core.c->get_sheet()->net_lines) {
+        for (const auto &it : core_schematic.get_sheet()->net_lines) {
             const auto line = it.second;
             bool add_line = false;
             for (auto &it_ft : {line.from, line.to}) {
@@ -849,14 +865,14 @@ void ImpSchematic::handle_move_to_other_sheet(const ActionConnection &conn)
                 new_sel.emplace(it.first, ObjectType::LINE_NET);
             }
         }
-        for (const auto &it : core.c->get_sheet()->lines) {
+        for (const auto &it : core_schematic.get_sheet()->lines) {
             for (const auto &it_ft : {it.second.from, it.second.to}) {
                 if (selection.count(SelectableRef(it_ft->uuid, ObjectType::JUNCTION))) {
                     new_sel.emplace(it.first, ObjectType::LINE);
                 }
             }
         }
-        for (const auto &it : core.c->get_sheet()->arcs) {
+        for (const auto &it : core_schematic.get_sheet()->arcs) {
             for (const auto &it_ft : {it.second.from, it.second.to, it.second.center}) {
                 if (selection.count(SelectableRef(it_ft->uuid, ObjectType::JUNCTION))) {
                     new_sel.emplace(it.first, ObjectType::ARC);
@@ -873,19 +889,19 @@ void ImpSchematic::handle_move_to_other_sheet(const ActionConnection &conn)
     }
     canvas->set_selection(selection);
 
-    auto old_sheet = core.c->get_sheet();
+    auto old_sheet = core_schematic.get_sheet();
     Sheet *new_sheet = nullptr;
     {
-        SelectSheetDialog dia(core.c->get_schematic(), old_sheet);
+        SelectSheetDialog dia(core_schematic.get_schematic(), old_sheet);
         dia.set_transient_for(*main_window);
         if (dia.run() == Gtk::RESPONSE_OK) {
-            new_sheet = &core.c->get_schematic()->sheets.at(dia.selected_sheet);
+            new_sheet = &core_schematic.get_schematic()->sheets.at(dia.selected_sheet);
         }
     }
     if (!new_sheet)
         return;
     sheet_box->select_sheet(new_sheet->uuid);
-    assert(core.c->get_sheet() == new_sheet);
+    assert(core_schematic.get_sheet() == new_sheet);
 
     // actually move things to new sheet
     for (const auto &it : selection) {
@@ -934,10 +950,10 @@ void ImpSchematic::handle_move_to_other_sheet(const ActionConnection &conn)
         default:;
         }
     }
-    core.c->get_schematic()->update_refs();
+    core_schematic.get_schematic()->update_refs();
 
-    core.c->commit();
-    core.c->rebuild();
+    core_schematic.set_needs_save();
+    core_schematic.rebuild();
     canvas_update();
     canvas->set_selection(selection);
     tool_begin(ToolID::MOVE);
@@ -958,4 +974,44 @@ std::pair<ActionID, ToolID> ImpSchematic::get_doubleclick_action(ObjectType type
     }
 }
 
+void ImpSchematic::update_unplaced()
+{
+    unplaced_box->update(core_schematic.get_schematic()->get_unplaced_gates());
+}
+
+void ImpSchematic::expand_selection_for_property_panel(std::set<SelectableRef> &sel_extra,
+                                                       const std::set<SelectableRef> &sel)
+{
+    for (const auto &it : sel) {
+        switch (it.type) {
+        case ObjectType::SCHEMATIC_SYMBOL:
+            sel_extra.emplace(core_schematic.get_schematic_symbol(it.uuid)->component->uuid, ObjectType::COMPONENT);
+            break;
+        case ObjectType::JUNCTION:
+            if (core->get_junction(it.uuid)->net) {
+                sel_extra.emplace(core->get_junction(it.uuid)->net->uuid, ObjectType::NET);
+            }
+            break;
+        case ObjectType::LINE_NET: {
+            LineNet &li = core_schematic.get_sheet()->net_lines.at(it.uuid);
+            if (li.net) {
+                sel_extra.emplace(li.net->uuid, ObjectType::NET);
+            }
+        } break;
+        case ObjectType::NET_LABEL: {
+            NetLabel &la = core_schematic.get_sheet()->net_labels.at(it.uuid);
+            if (la.junction->net) {
+                sel_extra.emplace(la.junction->net->uuid, ObjectType::NET);
+            }
+        } break;
+        case ObjectType::POWER_SYMBOL: {
+            PowerSymbol &sym = core_schematic.get_sheet()->power_symbols.at(it.uuid);
+            if (sym.net) {
+                sel_extra.emplace(sym.net->uuid, ObjectType::NET);
+            }
+        } break;
+        default:;
+        }
+    }
+}
 } // namespace horizon
