@@ -4,10 +4,11 @@
 #include "pool/part.hpp"
 #include "symbol_preview/symbol_preview_window.hpp"
 #include "widgets/unplaced_box.hpp"
+#include "core/tool_id.hpp"
 
 namespace horizon {
 ImpSymbol::ImpSymbol(const std::string &symbol_filename, const std::string &pool_path)
-    : ImpBase(pool_path), core_symbol(symbol_filename, *pool)
+    : ImpBase(pool_path), core_symbol(symbol_filename, *pool), searcher(core_symbol)
 {
     core = &core_symbol;
     core_symbol.signal_tool_changed().connect(sigc::mem_fun(*this, &ImpBase::handle_tool_change));
@@ -17,6 +18,7 @@ void ImpSymbol::canvas_update()
 {
     canvas->update(*core_symbol.get_canvas_data());
     symbol_preview_window->update(*core_symbol.get_canvas_data());
+    update_bbox_annotation();
 }
 
 void ImpSymbol::update_monitor()
@@ -33,11 +35,10 @@ void ImpSymbol::apply_preferences()
 void ImpSymbol::construct()
 {
 
-    main_window->set_title("Symbol - Interactive Manipulator");
     state_store = std::make_unique<WindowStateStore>(main_window, "imp-symbol");
 
     symbol_preview_window = new SymbolPreviewWindow(main_window);
-    symbol_preview_window->set_text_placements(core.y->get_symbol(false)->text_placements);
+    symbol_preview_window->set_text_placements(core_symbol.get_symbol()->text_placements);
     symbol_preview_window->signal_changed().connect([this] { core_symbol.set_needs_save(); });
     core_symbol.signal_tool_changed().connect(
             [this](ToolID tool_id) { symbol_preview_window->set_can_load(tool_id == ToolID::NONE); });
@@ -50,7 +51,7 @@ void ImpSymbol::construct()
             if (pl.count(key))
                 it.second.placement = pl.at(key);
         }
-        core_symbol.commit();
+        core_symbol.set_needs_save();
         core_symbol.rebuild();
         auto sel = canvas->get_selection();
         canvas_update();
@@ -70,7 +71,7 @@ void ImpSymbol::construct()
     unplaced_box->signal_place().connect([this](const auto &items) {
         std::set<SelectableRef> sel;
         for (const auto &it : items) {
-            sel.emplace(it, ObjectType::SYMBOL_PIN);
+            sel.emplace(it.at(0), ObjectType::SYMBOL_PIN);
         }
         this->tool_begin(ToolID::MAP_PIN, true, sel);
     });
@@ -80,26 +81,24 @@ void ImpSymbol::construct()
     core_symbol.signal_tool_changed().connect(
             [this](ToolID tool_id) { unplaced_box->set_sensitive(tool_id == ToolID::NONE); });
 
-    auto header_button = Gtk::manage(new HeaderButton);
-    header_button->set_label(core.y->get_symbol()->name);
+    header_button = Gtk::manage(new HeaderButton);
     main_window->header->set_custom_title(*header_button);
     header_button->show();
+    header_button->signal_closed().connect(sigc::mem_fun(*this, &ImpSymbol::update_header));
 
     name_entry = header_button->add_entry("Name");
-    name_entry->set_text(core.y->get_symbol()->name);
-    name_entry->set_width_chars(std::min<int>(core.y->get_symbol()->name.size(), 20));
-    name_entry->signal_changed().connect([this, header_button] {
-        header_button->set_label(name_entry->get_text());
-        core_symbol.set_needs_save();
-    });
+    name_entry->set_text(core_symbol.get_symbol()->name);
+    name_entry->set_width_chars(std::min<int>(core_symbol.get_symbol()->name.size(), 20));
+    name_entry->signal_changed().connect([this] { core_symbol.set_needs_save(); });
+    name_entry->signal_activate().connect(sigc::mem_fun(*this, &ImpSymbol::update_header));
 
-    unit_label = Gtk::manage(new Gtk::Label(core.y->get_symbol()->unit->name));
+    unit_label = Gtk::manage(new Gtk::Label(core_symbol.get_symbol()->unit->name));
     unit_label->set_xalign(0);
     unit_label->set_selectable(true);
     header_button->add_widget("Unit", unit_label);
 
     can_expand_switch = Gtk::manage(new Gtk::Switch);
-    can_expand_switch->set_active(core.y->get_symbol()->can_expand);
+    can_expand_switch->set_active(core_symbol.get_symbol()->can_expand);
     can_expand_switch->set_halign(Gtk::ALIGN_START);
     can_expand_switch->property_active().signal_changed().connect([this] { core_symbol.set_needs_save(); });
 
@@ -143,12 +142,11 @@ void ImpSymbol::construct()
                 [this, box](ToolID tool_id) { box->set_sensitive(tool_id == ToolID::NONE); });
     }
 
-    core.r->signal_rebuilt().connect([this] { unit_label->set_text(core.y->get_symbol()->unit->name); });
+    core->signal_rebuilt().connect([this] { unit_label->set_text(core_symbol.get_symbol()->unit->name); });
 
-    core.r->signal_save().connect([this, header_button] {
-        auto sym = core.y->get_symbol(false);
+    core->signal_save().connect([this] {
+        auto sym = core_symbol.get_symbol();
         sym->name = name_entry->get_text();
-        header_button->set_label(sym->name);
         sym->text_placements = symbol_preview_window->get_text_placements();
         sym->can_expand = can_expand_switch->get_active();
     });
@@ -167,12 +165,25 @@ void ImpSymbol::construct()
         hamburger_menu->append("Edit unit", "win.edit_unit");
         main_window->add_action("edit_unit", [this] { trigger_action(ActionID::EDIT_UNIT); });
     }
+
+    update_header();
+
+    bbox_annotation = canvas->create_annotation();
+    bbox_annotation->set_visible(true);
+    bbox_annotation->on_top = false;
+    bbox_annotation->set_display(LayerDisplay(true, LayerDisplay::Mode::OUTLINE));
+}
+
+void ImpSymbol::update_header()
+{
+    header_button->set_label(name_entry->get_text());
+    set_window_title(name_entry->get_text());
 }
 
 void ImpSymbol::update_unplaced()
 {
     const auto &pins_from_symbol = core_symbol.get_symbol()->pins;
-    std::map<UUID, std::string> unplaced;
+    std::map<UUIDPath<2>, std::string> unplaced;
     for (const auto &it : core_symbol.get_symbol()->unit->pins) {
         if (pins_from_symbol.count(it.first) == 0) {
             unplaced.emplace(it.first, it.second.primary_name);
@@ -181,4 +192,21 @@ void ImpSymbol::update_unplaced()
     unplaced_box->update(unplaced);
 }
 
+void ImpSymbol::update_bbox_annotation()
+{
+    if (!bbox_annotation)
+        return;
+    Coordi a;
+    for (const auto &it : core_symbol.get_symbol()->pins) {
+        const auto &p = it.second.position;
+        a = Coordi::max(a, {std::abs(p.x), std::abs(p.y)});
+    }
+    Coordi b = a * -1;
+    bbox_annotation->clear();
+    bbox_annotation->draw_line(a, Coordf(b.x, a.y), ColorP::PIN_HIDDEN, 0);
+    bbox_annotation->draw_line(Coordf(b.x, a.y), b, ColorP::PIN_HIDDEN, 0);
+    bbox_annotation->draw_line(b, Coordf(a.x, b.y), ColorP::PIN_HIDDEN, 0);
+    bbox_annotation->draw_line(Coordf(a.x, b.y), a, ColorP::PIN_HIDDEN, 0);
+}
+
 } // namespace horizon
