@@ -1,6 +1,7 @@
 #pragma once
 #include "imp.hpp"
 #include "core/core_symbol.hpp"
+#include "search/searcher_symbol.hpp"
 
 namespace horizon {
 class ImpSymbol : public ImpBase {
@@ -21,16 +22,27 @@ protected:
 
     void update_monitor() override;
 
+    Searcher *get_searcher_ptr() override
+    {
+        return &searcher;
+    };
+
 private:
     void canvas_update() override;
     void apply_preferences() override;
     CoreSymbol core_symbol;
+    SearcherSymbol searcher;
 
+    class HeaderButton *header_button = nullptr;
     Gtk::Entry *name_entry = nullptr;
     Gtk::Label *unit_label = nullptr;
     Gtk::Switch *can_expand_switch = nullptr;
     class SymbolPreviewWindow *symbol_preview_window = nullptr;
     class UnplacedBox *unplaced_box = nullptr;
     void update_unplaced();
+    void update_header();
+
+    class CanvasAnnotation *bbox_annotation = nullptr;
+    void update_bbox_annotation();
 };
 } // namespace horizon
