@@ -8,7 +8,7 @@
 namespace horizon {
 class RuleEditor : public Gtk::Box {
 public:
-    RuleEditor(Rule *r, class Core *c);
+    RuleEditor(Rule *r, class IDocument *c);
     virtual void populate();
     typedef sigc::signal<void> type_signal_updated;
     type_signal_updated signal_updated()
@@ -21,7 +21,7 @@ private:
 
 protected:
     Rule *rule;
-    class Core *core = nullptr;
+    class IDocument *core = nullptr;
     Glib::RefPtr<Gtk::Builder> builder;
     class SpinButtonDim *create_spinbutton(const char *box);
     class RuleMatchEditor *create_rule_match_editor(const char *box, class RuleMatch *match);
