@@ -1,8 +1,7 @@
 #include "rule_editor_clearance_copper_other.hpp"
 #include "board/rule_clearance_copper_other.hpp"
 #include "common/patch_type_names.hpp"
-#include "core/core.hpp"
-#include "core/core_board.hpp"
+#include "document/idocument.hpp"
 #include "rule_match_editor.hpp"
 #include "widgets/chooser_buttons.hpp"
 #include "widgets/parameter_set_editor.hpp"
