@@ -17,6 +17,7 @@
 #include "prj-mgr/prj-mgr_views.hpp"
 #include "pool-mgr/view_create_pool.hpp"
 #include "common/common.hpp"
+#include <git2.h>
 
 namespace horizon {
 using json = nlohmann::json;
@@ -78,6 +79,7 @@ public:
     void pool_notebook_go_to(ObjectType type, const UUID &uu);
     void open_pool(const std::string &pool_json, ObjectType type = ObjectType::INVALID, const UUID &uu = UUID());
     void handle_download(bool back_to_start = false);
+    void update_pool_cache_status_now();
 
 private:
     Glib::RefPtr<Gtk::Builder> builder;
@@ -132,6 +134,8 @@ private:
     void save_project();
     class PartBrowserWindow *part_browser_window = nullptr;
     class PoolCacheWindow *pool_cache_window = nullptr;
+    std::unique_ptr<class PoolCacheMonitor> pool_cache_monitor;
+    void cleanup();
 
     ViewMode view_mode = ViewMode::OPEN;
     void set_view_mode(ViewMode mode);
@@ -187,6 +191,10 @@ private:
 
     bool check_autosave(PoolProjectManagerProcess::Type type, const std::vector<std::string> &filenames);
 
+    static int git_transfer_cb(const git_transfer_progress *stats, void *payload);
+    bool downloading = false;
+    bool download_cancel = false;
+
 public:
     zmq::context_t &zctx;
     void set_pool_updating(bool v, bool success);
