@@ -90,6 +90,7 @@ static const LutEnumStr<ColorP> colorp_lut = {
         COLORP_LUT_ITEM(SEARCH_CURRENT),
         COLORP_LUT_ITEM(SHADOW),
         COLORP_LUT_ITEM(CONNECTION_LINE),
+        COLORP_LUT_ITEM(NOPOPULATE_X),
 };
 
 json CanvasPreferences::serialize() const
@@ -190,6 +191,7 @@ json ZoomPreferences::serialize() const
     json j;
     j["smooth_zoom_2d"] = smooth_zoom_2d;
     j["smooth_zoom_3d"] = smooth_zoom_3d;
+    j["touchpad_pan"] = touchpad_pan;
     return j;
 }
 
@@ -197,6 +199,7 @@ void ZoomPreferences::load_from_json(const json &j)
 {
     smooth_zoom_2d = j.value("smooth_zoom_2d", true);
     smooth_zoom_3d = j.value("smooth_zoom_3d", false);
+    touchpad_pan = j.value("touchpad_pan", false);
 }
 
 json KeySequencesPreferences::serialize() const
