@@ -68,7 +68,7 @@ Gtk::Label *grid_attach_label_and_widget(Gtk::Grid *gr, const std::string &label
 {
     auto la = Gtk::manage(new Gtk::Label(label));
     la->get_style_context()->add_class("dim-label");
-    la->set_halign(Gtk::ALIGN_END);
+    la->set_xalign(1);
     la->show();
     gr->attach(*la, 0, top, 1, 1);
     w->show();
@@ -225,4 +225,30 @@ Gtk::TreeViewColumn *tree_view_append_column_ellipsis(Gtk::TreeView *view, const
     return tvc;
 }
 
+void install_esc_to_close(Gtk::Window &win)
+{
+    win.signal_key_press_event().connect([&win](GdkEventKey *ev) {
+        if (ev->keyval == GDK_KEY_Escape) {
+            win.close();
+            return true;
+        }
+        else {
+            return false;
+        }
+    });
+}
+
+void widget_set_insensitive_tooltip(Gtk::Widget &w, const std::string &txt)
+{
+    if (txt.size()) {
+        w.set_tooltip_text(txt);
+        w.set_has_tooltip(true);
+        w.set_sensitive(false);
+    }
+    else {
+        w.set_has_tooltip(false);
+        w.set_sensitive(true);
+    }
+}
+
 } // namespace horizon
