@@ -1,9 +1,8 @@
 #include "net_class_button.hpp"
-#include "core/core.hpp"
 #include "block/block.hpp"
 
 namespace horizon {
-NetClassButton::NetClassButton(Core *c) : Gtk::ComboBoxText(), core(c)
+NetClassButton::NetClassButton(Block *c) : Gtk::ComboBoxText(), block(c)
 {
     update();
     signal_changed().connect([this] {
@@ -20,7 +19,7 @@ void NetClassButton::set_net_class(const UUID &uu)
 
 void NetClassButton::update()
 {
-    for (const auto &it : core->get_block()->net_classes) {
+    for (const auto &it : block->net_classes) {
         insert(0, (std::string)it.first, it.second.name);
     }
 }
