@@ -1,6 +1,6 @@
 major = 1
-minor = 0
-micro = 90
-name = "Aurora"
+minor = 1
+micro = 0
+name = "Blue sky"
 
 string = ".".join(str(x) for x in (major, minor, micro))
